# Introduction
Every mathematical function can be thought of as a set of ordered pairs, or an input value and an output value.
- Examples include $f(x) = x^2 + 2x + 1$, and $\{(1, 3), (2, 5), (4, 7)\}$.

**A limit describes how a function behaves *near* a point, rather than *at* that point.***
- As an example, given a *well behaved function* $f(x)$ and the fact that:
	- $f(1.9) = 8.41$
	- $f(1.999) = 8.99401$
	- $f(2.1) = 9.61$
	- $f(2.01) = 9.061$
	- $f(2.0001) = 9.0006$
	We can note that the smaller the distance of the input value $x$ to $2$, the smaller the distance of the output to $9$. This is most commonly described in the terms "As $x$ approaches $2$, $f(x)$ approaches $9$", or "As $x \to 2$, $f(x) \to 9$."

Limits are valuable because they can be used to describe a point on a graph, even if that point is not present.
# Standard Notation
The standard notation for a limit is:
$$ \lim_{x \to a} f(x) = L $$
- As $x$ approaches $a$, the output of $f(x)$ draws closer to $L$. In the above notation, $x$ and $a$ are not necessarily equal.
- When plotted, the hole is located at $(a, L)$.

# Continuity
A function is continuous if their graph can be traced with a pencil without lifting the pencil from the page.

Formally, a function $f$ is continuous at a point $a$ if:
- $f(a)$ is defined
- $\lim_{x \to a} f(x)$  exists
- $\lim_{x \to a} = f(a)$

- A function is continuous on the open interval $(a, b)$ if it is continuous at all points between $a$ and $b$
- A function is continuous on the closed interval $[a, b]$ if it is continuous at all points between $a$ and $b$

# Elementary Functions
An elementary function is any function that is defined using:
- Polynomial functions
- Rational functions
- Root functions
- Trig functions
- Inverse trig functions
- Exponential functions
- Logarithmic functions
- Operations of:
	- Addition
	- Subtraction
	- Multiplication
	- Division
	- Composition

A piece-wise function is *not*  considered an elementary function

- If $f$ and $g$ are continuous at a point $x = a$ and $c$ is a constant then the following functions are also continuous at $x = a$
- If $g$ is continuous at $a$ and $f$ is continuous at $g(a)$, then $f(g(a))$ is continuous at $a$
- If $f$ is an elementary function and if $a$ is in the domain of $f$, then $f$ is continuous at $a$
Together, the above theorems tell us that if $a$ is in the domain of an elementary function, then $\lim_{x \to a} f(x) = f(a)$.

# Intermediate Value Theorem
Let $f$ be a continuous function on the interval ${}

# Definitions

| Term                  | Definition                                                                    |
| --------------------- | ----------------------------------------------------------------------------- |
| Well behaved function | A function that is continuous, has a single value, and is defined everywhere. |




